@@ -24,9 +24,7 @@ $skip = ( $@ or not -r '/etc/debian_version') ? 1 : 0 ;
         load_check => 'no',
         check => {
             'Files:"*" License full_license' => "[PSF LICENSE TEXT]",
-            'Files:"*" Copyright:0' => "2008, John Doe <john.doe\@example.com>",
-            'Files:"*" Copyright:1' =>
-              "2007, Jane Smith <jane.smith\@example.com>",
+            'Files:"*" Copyright' => "2008, John Doe <john.doe\@example.com>\n2007, Jane Smith <jane.smith\@example.com>",
             'Files:"*" License short_name' => "PsF",
             '"Xtest"'                     => "yada yada\n\nyada",
             '"Upstream-Name"'              => "xyz",
@@ -103,27 +101,29 @@ $skip = ( $@ or not -r '/etc/debian_version') ? 1 : 0 ;
     },
     { # t7
         # example from CANDIDATE DEP-5 spec (nb 7)
-        load_warnings => [ (qr/Adding/) x 1 ],
+        load_warnings => [ (qr/Adding/) x 1 , qr/Format does not match/ ],
         load_check => 'no',
+        apply_fix => 1,
         check => { 
-            Format => "http://dep.debian.net/deps/dep5/", 
-            'Files:"*" Copyright:0' => 'Copyright 1998 John Doe <jdoe@example.com>',
+            Format => "http://www.debian.org/doc/packaging-manuals/copyright-format/1.0/", 
+            'Files:"*" Copyright' => 'Copyright 1998 John Doe <jdoe@example.com>',
             'Files:"debian/*" License short_name' => 'other',
             },
     },
     {
         # test nb 8
+        load_warnings => [ qr/Format does not match/ ],
+        apply_fix => 1,
         check => { 
-            Format => "http://dep.debian.net/deps/dep5/", 
-            'Files:"*" Copyright:0' => '2008, John Doe <jdoe@example.com>',
-            'Files:"*" Copyright:1' =>          '2007, Jane Smith <jsmith@example.org>',
-            'Files:"*" Copyright:2' =>          '2007, Joe Average <joe@example.org>',
-            'Files:"*" Copyright:3' =>          '2007, J. Random User <jr@users.example.com>',
+            Format => "http://www.debian.org/doc/packaging-manuals/copyright-format/1.0/", 
+            'Files:"*" Copyright' => "2008, John Doe <jdoe\@example.com>\n2007, Jane Smith <jsmith\@example.org>\n2007, Joe Average <joe\@example.org>\n2007, J. Random User <jr\@users.example.com>",
             },
         },
     {
+        load_warnings => [ qr/Format does not match/ ],
+        apply_fix => 1,
         check => {
-            'Files:"*" Copyright:0' => 'foo',
+            'Files:"*" Copyright' => 'foo',
             'Files:"*" License short_name' => 'BSD',
             'Files:"*" License full_license' => ' foo bar',
         },
@@ -132,7 +132,7 @@ $skip = ( $@ or not -r '/etc/debian_version') ? 1 : 0 ;
         load_warnings => [ (qr/deprecated/) x 2 ],
 
         check => { 
-            Format => "http://dep.debian.net/deps/dep5/", 
+            Format => "http://www.debian.org/doc/packaging-manuals/copyright-format/1.0/", 
             # something's wrong with utf8 string checks
             #'Debianized-By' => 'Picca Frédéric-Emmanuel <picca@synchrotron-soleil.fr>',
             Source => 'http://tango-controls.org/download',
@@ -142,6 +142,8 @@ $skip = ( $@ or not -r '/etc/debian_version') ? 1 : 0 ;
     },
 
     { # t11 Debian bug #610231
+        load_warnings => [ qr/Format does not match/ ],
+        apply_fix => 1,
         dump_errors =>  [ 
             qr/mandatory/ => 'Files:"*" Copyright:0="(c) foobar"',
             qr/mandatory/ => ' License:FOO text="foo bar" ! Files:"*" License short_name="FOO" '
@@ -157,9 +159,13 @@ $skip = ( $@ or not -r '/etc/debian_version') ? 1 : 0 ;
     },
 
     { # t13 Debian bug #624305
+        load_warnings => [ qr/Format does not match/ ],
+        apply_fix => 1,
     },
     { # t14 Debian bug #633847
         # need to change License model from Hash of leaves to hash of nodes 
+        load_warnings => [ qr/Format does not match/ ],
+        apply_fix => 1,
         check => { 
             'Comment' => "On Debian systems, copies of the GNU General Public License version 1
 and Lesser General Public License version 2.1 can be found respectively in
